@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2002 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ typedef struct _GMimeFilterFromClass GMimeFilterFromClass;
 typedef enum {
 	GMIME_FILTER_FROM_MODE_DEFAULT  = 0,
 	GMIME_FILTER_FROM_MODE_ESCAPE   = 0,
-	GMIME_FILTER_FROM_MODE_ARMOR    = 1,
+	GMIME_FILTER_FROM_MODE_ARMOR    = 1
 } GMimeFilterFromMode;
 
 struct _GMimeFilterFrom {
