@@ -35,7 +35,7 @@ int g_gethostbyname_r (const char *name, struct hostent *host,
 		       char *buf, size_t buflen, int *herr);
 
 int g_gethostbyaddr_r (const char *addr, int addrlen, int af,
-		       struct hostent *hostbuf, char *buf,
+		       struct hostent *host, char *buf,
 		       size_t buflen, int *herr);
 
 #ifdef __cplusplus
