@@ -61,6 +61,9 @@ GType g_mime_stream_file_get_type (void);
 GMimeStream *g_mime_stream_file_new (FILE *fp);
 GMimeStream *g_mime_stream_file_new_with_bounds (FILE *fp, off_t start, off_t end);
 
+gboolean g_mime_stream_file_get_owner (GMimeStreamFile *stream);
+void g_mime_stream_file_set_owner (GMimeStreamFile *stream, gboolean owner);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
